# rest-auth
Service in charge of authentication

Set up to develop
1. Install requirements.txt
2. Start database server "pg_ctl -D /usr/local/var/postgres/ start"
3. Create flask_api database "createdb flask_api"